'use strict';
/*
 *  Jazz Jackrabbit 2 Launcher created by DJazz
 *  http://djazz.mine.nu/
 *  Usage:
 *    jj2://password@host:port/?v=version
 *  
 *  host can be a hostname or an IPv4 address
 *  port is only needed if server is on a port other than the default port 10052
 *  ?v=version is only needed if you want to specify server version and choosing the right client version. See plus-readme.txt for a list of possible values.
 *  password is only needed for passworded servers. Trying to join a server without password will lead to a Network Error
 *  
 *  Examples:
 *    jj2://1.2.3.4/
 *    jj2://myhost.com/v?=24
 *    jj2://password@1.2.3.4/
 *  
 *  HTML example:
 *    <a href="jj2://11.22.33.44/">Join my server!</a>
 *  
 *  Enjoy!
 */

// Note that you need double backslashes for path

var isPlus = true; // Don't have JJ2+?

var debug = false; // Change to true for debugging

process.title = "Jazz Jackrabbit 2 Launcher";

var iniparse = require('./iniparse.js');
var child_process = require('child_process');
var dns = require('dns');
var url = require('url');
var path = require('path');

iniparse.parse(path.resolve(path.dirname(process.argv[1]), './jj2launcher_settings.ini'), function (err, settings) {
	
	if(err || !settings.paths) {
		console.log("Unable to read settings file, can't continue. Does the settings file exist?");
		setInterval(function () {}, 30*1000);
		return;
	}
	
	
	if(!process.argv[2]) {
		console.log("What are you doing?");
		setInterval(function () {}, 30*1000);
	}
	else {
		
		var uri = url.parse(process.argv[2], true);

		if(debug) {
			console.log("Input URI scheme:", process.argv[2]);
			console.log("Parsed URI:", uri);
			setInterval(function () {}, 30*1000);
		}
		
		var jj2path = settings.paths['v1.23']; // Leave blank if you don't have 1.23
		var jj2tsfpath = settings.paths['v1.24']; // Leave blank if you don't have TSF
		
		if(!jj2tsfpath) jj2tsfpath = jj2path;
		if(!jj2path) jj2path = jj2tsfpath;

		var host = uri.hostname || "localhost";
		var port = (+uri.port) || 10052;
		var password = uri.auth || "";
		var server_version = (uri.query.v && uri.query.v.trim()) || '';
		if(server_version.indexOf('24') > -1) {
			jj2path = jj2tsfpath;
		}

		if(!isPlus && port !== 10052) {
			console.log("Error:\n\rNormal JJ2 can't join servers with hosted on other ports than 10052.\n\rYou tried to join a server with the port "+port);
			setInterval(function () {}, 30*1000);
		}
		else {
			dns.lookup(host, function (err, address, family) {
				
				var args;
				if(isPlus) {
					args = ['-connect', address+(port===10052?'':':'+port)+'/'+password.replace(/\//g, "")+'/'+server_version];
				}
				else {
					args = ['-connect', address];
				}
				console.log("Starting JJ2, command:");
				console.log(jj2path, args);
				child_process.execFile(jj2path, args);
				
				console.log("\n\rgl hf!");
				
				if(!debug) {
					process.exit(0);
				}
			});
		}
	}
});